/*
 * COPYRIGHT (C) 2008, CANTATA
 *
 * CANTATA-RACE/RMC:
 * rmc_debug.c
 *
 * DESCRIPTION:
 * Debugging utils used for Resource Manager Component (RMC).
 *
 * See rmc.h for a description of the RMC.
 *
 * HISTORY:
 * 2008-29-05   0.3  Mike Holenderski (TU/e)
 *                   - add dynamic memory allocation within budgets
 */

#include "rmc_types.h"

/* Print debugging output, if DEBUG is defined.
 *
 * Debug levels (which methods will print):
 *   1 : debug() + warning()
 *   2 : warning()
 */


//#define DEBUG 2


/* Debugging output macro */

#ifdef DEBUG
#include <stdio.h>

#define warning(...)  { printf("WARNING: "); printf (__VA_ARGS__); (void) printf("\n");}

#if DEBUG == 1

#define debug(...)  { (void) fprintf (stdout, __VA_ARGS__); }

void printb(RMC_MemoryBudgetHeadType* pBudget, char* header);
#define debugb(...)  { (void) printb (__VA_ARGS__); }

void printFreeList(RMC_MemoryBudgetHeadType* pBudget, char* header);
#define debugFreeList(...)  { (void) printFreeList (__VA_ARGS__); }

#else

#define debug(...)  ((void) 0)
#define debugb(...)  ((void) 0)
#define debugFreeList(...)  ((void) 0)
#endif
#else
/*
inline void dummy(void *x, ...)
{
}

#define debug dummy
#define debugb dummy
#define debugFreeList dummy
#define warning dummy

*/
 #define debug(...)  ((void) 0)
#define debugb(...)  ((void) 0)
#define debugFreeList(...)  ((void) 0)

#define warning(...)  ((void) 0) 

#endif