/*
 * COPYRIGHT (C) 2008, CANTATA
 *
 * CANTATA-RACE/RMC:
 * rmc_types.h
 *
 * DESCRIPTION:
 * Types used by the RMC implementation in rmc.c, which are shared between
 * several RMC files.
 *
 * HISTORY:
 * 2008-09-06   0.4  Mike Holenderski (TU/e)
 */

#ifndef __CR_RMC_TYPES__
#define __CR_RMC_TYPES__

#ifdef __cplusplus
extern "C" {
#endif

#include "rmc.h"

/*
 * MemoryAllocation info stores all allocation information required by the RMC
 * throughout the lifetime of a memory allocation within a budget. It is also the
 * header of a memory allocation in a list of allocations.
 */
 
typedef struct _RMC_MemoryAllocationHeadType RMC_MemoryAllocationHeadType;

struct _RMC_MemoryAllocationHeadType {
	RMC_MemorySizeType size;
  RMC_MemoryAllocationHeadType *next;
};

/*
 * MemoryBudget info stores all budget information required by the RMC
 * throughout the lifetime of the budget. It is also a header of a budget in the 
 * global list of budgets.
 */

typedef struct _RMC_MemoryBudgetHeadType RMC_MemoryBudgetHeadType;

struct _RMC_MemoryBudgetHeadType {
  RMC_MemorySizeType size;     /* size in bytes */
  RMC_MemoryBudgetHeadType* next;
  CR_ObjectType owner;         /* component instance owning this budget */
  CR_UInt32 maxNumberOfAllocations; /* maximum number of allocations inside this budget */
  RMC_MemorySizeType utilization;     /* current utilization of the budget */
  RMC_MemoryAllocationHeadType* freeList; /* pointer to the beginning of available
                                             memory locations */
  RMC_MemoryAllocationHeadType* allocatedList; /* pointer to the beginning of
                                                allocated memory locations */
};

/*
 * Sizes of the internal data structures associated with every budget and
 * memory allocation.
 * IMPORTANT: must correspond to the size of the head types in the implementation!
 */


#ifdef __cplusplus
}
#endif

#endif /* __CR_RMC__ */